﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;
using BuiltToRoam;
using BuiltToRoam.SocialReader;
using BuiltToRoam.SocialReader.Lists;
using BuiltToRoam.SocialReader.Pages.Main;

namespace $safeprojectname$.Pages.Main
{
    public class MainPageViewModel: MainPageViewModelBase
    {
        public MainPageViewModel(IRepository repository)
            : base(repository)
        {
            
            // (Optional) This sets the minimum latency between SocialFeedLoaded events. Increasing
            // this will increase load time for all feed data but will allow the UI
            // to be more responsive
            Repository.UpdateThresholdInMilliseconds = 100;

            // (Optional) This is the maximum number of social activities that will be cached.
            Repository.MaximumActivitiesToCache = 50;
        }
        
        /// <summary>
        /// (Optional) Override this method to dynamically do stuff with new activities
        /// </summary>
        protected override void AddingSocialActivity(SocialActivity newActivity)
        {
            base.AddingSocialActivity(newActivity);
           
        }
        
        /// <summary>
        /// Call this method to refresh activities
        /// </summary>
        public void RefreshActivities()
        {
            Repository.Refresh();
        }


        public override void DisplaySocialActivity(ISocialActivityWrapper item, IEnumerable<ISocialActivityWrapper> list)
        {
            if (!Repository.IsInFullMode)
            {
                if (Repository.IsInTrialMode)
                {
                    var days = Repository.TrialExpiresOn.Date.Subtract(DateTime.Now.Date).Days;
                    var daysToGo = days + (days > 1 ? " days" : " day");

                    MessageBox.Show("You have " + daysToGo + " remaining until the trial period expires");
                }
                else
                {
                    MessageBox.Show(
                        "Trial mode has expired, please purchage this application in order to view item details");
                    return;
                }
            }


            
            base.DisplaySocialActivity(item, list);
        }

#region Databinding Properties
        
        public string ApplicationTitle
        {
            get
            {
                return Utilities.ApplicationTitle;
            }
        }


#endregion
    }
}
